==========
SEAMM Util
==========



.. image:: https://img.shields.io/pypi/v/seamm_util.svg
        :target: https://pypi.python.org/pypi/seamm_util

.. image:: https://travis-ci.org/molssi-seamm/seamm_util.svg?branch=master
        :target: https://travis-ci.org/molssi-seamm/seamm_util

.. image:: https://readthedocs.org/projects/seamm-util/badge/?version=latest
        :target: https://seamm-util.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/seamm_util/shield.svg
     :target: https://pyup.io/repos/github/molssi-seamm/seamm_util/
     :alt: Updates

.. image:: https://codecov.io/gh/molssi-seamm/seamm_util/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/molssi-seamm/seamm_util


Utility classes and functions that support other SEAMM tools


* Free software: BSD license
* Documentation: https://seamm-util.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

